@@ -42,7 +42,7 @@ class SimplifiedInterfaceMediaDefiningClass(MediaDefiningClass):
 class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
 
     def __init__(self, component_name):
-        self.__component_name = component_name
+        self._component_name = component_name
         self.instance_template = None
         self.slots = {}
 
@@ -90,7 +90,7 @@ class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
             if settings.DEBUG:
                 warnings.warn(
                     "Component {} was provided with unexpected slots: {}".format(
-                        self.__component_name, unexpected_slots
+                        self._component_name, unexpected_slots
                     )
                 )
             for unexpected_slot in unexpected_slots:
